---
title: Introduction
sidebar: doc_sidebar
permalink: doc_introduction.html
folder: doc
---


Computional Fluid Dynamics is applied in numerous engineering fields including aerospace, automotive, chemical, marine and many more. However, the fluid flow is not the only aspect in a sucessful product design. Boundary condition are often coupled with another disciple such as mechanics and thermal and many more. OpenFOAM has its strength in flow simulation and is capable of simulating numerous flow types. The goal of this library is to provide a external coupling interface for OpenFOAM to improve your input.

The design of the library and describes in couple your code

## Getting started

To get started, see [Getting Started][index].


## Input and Output parameters

A list of the input parameters are here [Input][index].

A list of the output parameters are here [Output][index].

{% include links.html %}